#include <iostream>
#include <cstdio>
#include <sstream>
#include <vector>
#include <algorithm>
#include <string>
#include <cmath>

typedef double Num;

class vec2d  {
private:
  void cp(Num xx, Num yy)  {x = xx;  y = yy;}
public:
  Num x,y;
  vec2d(const Num x = 0, const Num y = 0)  {cp(x,y);}
  vec2d(const vec2d& p)  {cp(p.x,p.y);}
  vec2d& operator= (const vec2d& q)  {cp(q.x,q.y);  return *this;}
};

Num len(const vec2d& p)  {return hypot(p.x,p.y);}
vec2d operator+ (const vec2d& p, const vec2d& q)  {return vec2d(p.x+q.x,p.y+q.y);}
vec2d operator- (const vec2d& p)  {return vec2d(-p.x,-p.y);}
vec2d operator- (const vec2d& p, const vec2d& q)  {return p+-q;}
vec2d operator* (const Num c, const vec2d& q)  {return vec2d(c*q.x,c*q.y);}
vec2d operator/ (const vec2d& p, const Num c)  {return vec2d(p.x/c,p.y/c);}
Num operator* (const vec2d& p, const vec2d& q)  {return p.x*q.x+p.y*q.y;}
vec2d operator~ (const vec2d& p)  {return vec2d(-p.y,p.x);}
Num operator^ (const vec2d& p, const vec2d& q)  {return ~p*q;}
bool operator< (const vec2d& p, const vec2d& q)  {return (p^q)>0;}

#define M 1000

using namespace std;

typedef vector<vec2d> pnts;

// намиране на пресечна точка на права през o с посока u и отсечка [p,q]
vec2d xpoint(vec2d & o, vec2d & u, vec2d & p, vec2d & q)  {
  vec2d v = q-p;
  return p+(u^(p-o))/(v^u)*v;
}

// отсичане на po1 посредством изпъкналия po2; резултатът отива в po
void xsectpoly(const pnts & po1, const pnts & po2, pnts & po)  {
  int i,j,m,n;
  pnts r1(po1), r2;
  for (m=po2.size(),i=0; i<m; ++i,r1=r2)  {
    r2.resize(0);
    vec2d o = po2[i];
    vec2d u = po2[(i+1)%m]-o;
    for (n=r1.size(),j=0; j<n; ++j)  {
      vec2d p = r1[j], q = r1[(j+1)%n];
      vec2d v1 = p-o, v2 = q-o;
      if (v2<u)  {
        if (u<v1)  r2.push_back(xpoint(o,u,p,q));
      }  else {
        if (v1<u)  {
          vec2d xp = xpoint(o,u,p,q);
          if (len(xp-q)>.00001)  r2.push_back(xp);
        }
        r2.push_back(q);
      }
    }
  }
  po = r2;
}

void readpnts(pnts & po)  {
  string s;
  vec2d p;
  po.reserve(M);
  for (;;)  {
    getline(cin,s);
    istringstream sstr(s);
    if (!(sstr >> p.x >> p.y))  break;
    po.push_back(p);
  }
}

Num area(const pnts & po)  {
  int m = po.size();
  double a = 0.;
  for (int i=0; i<m; ++i)  a += po[i]^po[(i+1)%m];
  return a/2.;
}

int main()  {
  pnts po1,po2,po;
  readpnts(po1);  if (area(po1)<0.)  reverse(po1.begin(),po1.end());
  readpnts(po2);  if (area(po2)<0.)  reverse(po2.begin(),po2.end());
  xsectpoly(po1,po2,po);
  printf("%.2f\n",area(po));
  return 0;
}
